pub fn render_json_matrix(reports: &[CapabilityReport]) -> Result<String>Expand description
Render capability reports as JSON using the SDK report shape.
Errors
Returns a JSON serialization error if a report cannot be serialized.
pub fn render_json_matrix(reports: &[CapabilityReport]) -> Result<String>Render capability reports as JSON using the SDK report shape.
Returns a JSON serialization error if a report cannot be serialized.