pub fn dispatch_to_plugin(
entry: &PluginEntry,
args: &[OsString],
contract: &EnvContract,
) -> ExitCodeExpand description
Dispatch into entry with args, exporting the env contract.
Returns the plugin’s exit code.
pub fn dispatch_to_plugin(
entry: &PluginEntry,
args: &[OsString],
contract: &EnvContract,
) -> ExitCodeDispatch into entry with args, exporting the env contract.
Returns the plugin’s exit code.