invoke_go

Function invoke_go 

pub fn invoke_go(
    provider: &ProviderId,
    capability: &str,
    args: &[OsString],
    contract: &EnvContract,
    capture_json: bool,
) -> Result<GoInvocation>
Invoke <provider> __go <capability> ....

When capture_json is true, stdout is parsed as a CapabilityRunReport. Unlike set, a nonzero provider exit can still return a valid failed workflow report.

Errors

Returns I/O errors from spawning the provider process.