detect_project_root

Function detect_project_root 

pub fn detect_project_root(cwd: &Path) -> Option<PathBuf>
Walk upward from cwd to detect a project root. Returns None if the filesystem root is reached without finding any marker.